@@ -48,6 +48,7 @@
 #include <OpenImageIO/export.h>
 #include <OpenImageIO/hash.h>
 #include <OpenImageIO/oiioversion.h>
+#include <OpenImageIO/platform.h>
 #include <OpenImageIO/string_view.h>
 
 // For now, let a prior set of OIIO_USE_FMT=0 cause us to fall back to
@@ -312,13 +313,21 @@ std::string OIIO_API escape_chars (string_view unescaped);
 /// and collapse them into the 'real' characters.
 std::string OIIO_API unescape_chars (string_view escaped);
 
-/// Word-wrap string 'src' to no more than columns width, splitting at
-/// space characters.  It assumes that 'prefix' characters are already
-/// printed, and furthermore, if it should need to wrap, it prefixes that
-/// number of spaces in front of subsequent lines.  By illustration, 
-/// wordwrap("0 1 2 3 4 5 6 7 8", 4, 10) should return:
-/// "0 1 2\n    3 4 5\n    6 7 8"
-std::string OIIO_API wordwrap (string_view src, int columns=80, int prefix=0);
+/// Word-wrap string `src` to no more than `columns` width, starting with an
+/// assumed position of `prefix` on the first line and intending by `prefix`
+/// blanks before all lines other than the first.
+///
+/// Words may be split AT any characters in `sep` or immediately AFTER any
+/// characters in `presep`. After the break, any extra `sep` characters will
+/// be deleted.
+///
+/// By illustration,
+///     wordwrap("0 1 2 3 4 5 6 7 8", 10, 4)
+/// should return:
+///     "0 1 2\n    3 4 5\n    6 7 8"
+std::string OIIO_API wordwrap (string_view src, int columns = 80,
+                               int prefix = 0, string_view sep = " ",
+                               string_view presep = "");
 
 /// Hash a string_view.
 inline size_t
@@ -793,6 +802,13 @@ bool OIIO_API parse_identifier_if (string_view &str, string_view id,
 string_view OIIO_API parse_until (string_view &str,
                                   string_view sep=" \t\r\n", bool eat=true);
 
+/// Return the characters at the head of the string that match any in set,
+/// and additionally modify str to skip over the parsed section if eat is
+/// also true. Otherwise, if no `set` characters are found at the beginning
+/// of str, return an empty string_view and don't modify str.
+string_view OIIO_API parse_while (string_view &str,
+                                  string_view set, bool eat=true);
+
 /// Assuming the string str starts with either '(', '[', or '{', return the
 /// head, up to and including the corresponding closing character (')', ']',
 /// or '}', respectively), recognizing nesting structures. For example,
@@ -804,6 +820,15 @@ string_view OIIO_API parse_until (string_view &str,
 string_view OIIO_API parse_nested (string_view &str, bool eat=true);
 
 
+/// Look within `str` for the pattern:
+///     head nonwhitespace_chars whitespace
+/// Remove that full pattern from `str` and return the nonwhitespace
+/// part that followed the head (or return the empty string and leave `str`
+/// unmodified, if the head was never found).
+OIIO_API std::string
+excise_string_after_head (std::string& str, string_view head);
+
+
 /// Converts utf-8 string to vector of unicode codepoints. This function
 /// will not stop on invalid sequences. It will let through some invalid
 /// utf-8 sequences like: 0xfdd0-0xfdef, 0x??fffe/0x??ffff. It does not
