@@ -209,6 +209,12 @@ test_wordwrap()
     OIIO_CHECK_EQUAL(Strutil::wordwrap(words, 24), "Now is the time for all\n"
                                                    "good men to come to the\n"
                                                    "aid of their party.");
+    std::string densewords
+        = "Now is the,time,for,all,good,men,to,come to the aid of their party.";
+    OIIO_CHECK_EQUAL(Strutil::wordwrap(densewords, 24, 0, " ", ","),
+                     "Now is the,time,for,all,\n"
+                     "good,men,to,come to the\n"
+                     "aid of their party.");
 }
 
 
@@ -422,6 +428,31 @@ test_replace()
 
 
 
+void
+test_excise_string_after_head()
+{
+    std::cout << "Testing excise_string_after_head\n";
+    std::string pattern = "Red rose, red rose, end.";
+
+    // test non-match
+    {
+        std::string p = pattern;
+        auto m = Strutil::excise_string_after_head(p, "blue");
+        OIIO_CHECK_EQUAL(p, pattern);
+        OIIO_CHECK_EQUAL(m, "");
+    }
+
+    // test match: head is "ro", match subsequent chars to the next space
+    {
+        std::string p = pattern;
+        auto m = Strutil::excise_string_after_head(p, "ro");
+        OIIO_CHECK_EQUAL(p, "Red red rose, end.");
+        OIIO_CHECK_EQUAL(m, "se,");
+    }
+}
+
+
+
 void
 test_numeric_conversion()
 {
@@ -535,10 +566,10 @@ test_numeric_conversion()
     std::string numstring (numcstr);
     bench ("get default locale", [](){ std::locale loc; DoNotOptimize (loc); });
     bench ("ref classic locale", [](){ DoNotOptimize (std::locale::classic()); });
-    bench ("std atoi", [&](){ DoNotOptimize(atoi(numcstr));});
+    bench ("std atoi", [&](){ DoNotOptimize(atoi(numcstr));}); // NOLINT(cert-err34-c)
     bench ("Strutil::stoi(string) ", [&](){ return DoNotOptimize(Strutil::stoi(numstring)); });
     bench ("Strutil::stoi(char*) ", [&](){ return DoNotOptimize(Strutil::stoi(numcstr)); });
-    bench ("std atof", [&](){ DoNotOptimize(atof(numcstr));});
+    bench ("std atof", [&](){ DoNotOptimize(atof(numcstr));}); // NOLINT(cert-err34-c)
     bench ("std strtod", [&](){ DoNotOptimize(::strtod(numcstr, nullptr));});
     bench ("Strutil::from_string<float>", [&](){ DoNotOptimize(Strutil::from_string<float>(numstring));});
     bench ("Strutil::stof(string) - locale-independent", [&](){ return DoNotOptimize(Strutil::stof(numstring)); });
@@ -700,6 +731,30 @@ test_string_view()
     OIIO_CHECK_EQUAL(sr.rfind('1', 4), s.rfind('1', 4));
     OIIO_CHECK_EQUAL(sr.rfind('1', 4), 1);
     OIIO_CHECK_EQUAL(sr.rfind('5', 4), string_view::npos);
+
+    OIIO_CHECK_EQUAL(sr.find_first_of('2'), 2);
+    OIIO_CHECK_EQUAL(sr.find_first_of("23"), 2);
+    OIIO_CHECK_EQUAL(sr.find_first_of("xyz"), string_view::npos);
+    OIIO_CHECK_EQUAL(sr.find_first_of('2', 5), 7);
+    OIIO_CHECK_EQUAL(sr.find_first_of("23", 5), 7);
+
+    OIIO_CHECK_EQUAL(sr.find_last_of('2'), 7);
+    OIIO_CHECK_EQUAL(sr.find_last_of("23"), 8);
+    OIIO_CHECK_EQUAL(sr.find_last_of("xyz"), string_view::npos);
+    OIIO_CHECK_EQUAL(sr.find_last_of('2', 5), 2);
+    OIIO_CHECK_EQUAL(sr.find_last_of("23", 5), 3);
+
+    OIIO_CHECK_EQUAL(sr.find_first_not_of('0'), 1);
+    OIIO_CHECK_EQUAL(sr.find_first_not_of("012"), 3);
+    OIIO_CHECK_EQUAL(sr.find_first_not_of('0', 5), 6);
+    OIIO_CHECK_EQUAL(sr.find_first_not_of("012", 5), 8);
+    OIIO_CHECK_EQUAL(sr.find_first_of("xyz"), string_view::npos);
+
+    OIIO_CHECK_EQUAL(sr.find_last_not_of('4'), 8);
+    OIIO_CHECK_EQUAL(sr.find_last_not_of("234"), 6);
+    OIIO_CHECK_EQUAL(sr.find_last_not_of('4', 5), 3);
+    OIIO_CHECK_EQUAL(sr.find_last_not_of("234", 5), 1);
+    OIIO_CHECK_EQUAL(sr.find_last_of("xyz"), string_view::npos);
 }
 
 
@@ -801,6 +856,11 @@ void test_parse ()
     s = "foo;bar blow"; ss = parse_until (s, "/");
     OIIO_CHECK_ASSERT (ss == "foo;bar blow" && s == "");
 
+    s = "foo;bar blow"; ss = parse_while (s, "of");
+    OIIO_CHECK_ASSERT (ss == "foo" && s == ";bar blow");
+    s = "foo;bar blow"; ss = parse_while (s, "abc");
+    OIIO_CHECK_ASSERT (ss == "" && s == "foo;bar blow");
+
     s = "[a([b]c)]x]"; ss = parse_nested (s);
     OIIO_CHECK_EQUAL (ss, "[a([b]c)]"); OIIO_CHECK_EQUAL (s, "x]");
     s = "[a([b]c)]x]"; ss = parse_nested (s, false);
@@ -822,8 +882,8 @@ test_locale()
               << Strutil::stof(numcstr) << "\n";
     OIIO_CHECK_EQUAL_APPROX(Strutil::stof(numcstr), 123.45f);
     std::cout << "unsafe float convert (default locale) " << numcstr << " = "
-              << atof(numcstr) << "\n";
-    OIIO_CHECK_EQUAL_APPROX(atof(numcstr), 123.0f);
+              << atof(numcstr) << "\n"; // NOLINT(cert-err34-c)
+    OIIO_CHECK_EQUAL_APPROX(atof(numcstr), 123.0f); // NOLINT(cert-err34-c)
 
     // Verify that Strutil::sprintf does the right thing, even when in a
     // comma-based locale.
@@ -894,6 +954,7 @@ main(int argc, char* argv[])
     test_join();
     test_repeat();
     test_replace();
+    test_excise_string_after_head();
     test_numeric_conversion();
     test_to_string();
     test_extract();
