@@ -51,17 +51,6 @@
 
 #include "imageio_pvt.h"
 
-#ifdef USE_BOOST_REGEX
-#    include <boost/regex.hpp>
-using boost::regex;
-using boost::regex_replace;
-#else
-#    include <regex>
-using std::regex;
-using std::regex_replace;
-#endif
-
-
 
 OIIO_PLUGIN_NAMESPACE_BEGIN
 
@@ -685,11 +674,12 @@ TIFFInput::seek_subimage(int subimage, int miplevel)
                                || m_photometric == PHOTOMETRIC_ITULAB
                                || m_photometric == PHOTOMETRIC_LOGL
                                || m_photometric == PHOTOMETRIC_LOGLUV);
-        if (is_jpeg || (is_nonspectral && !m_raw_color)) {
+        if ((is_jpeg && m_spec.nchannels != 3)
+            || (is_nonspectral && !m_raw_color)) {
             char emsg[1024];
             m_use_rgba_interface = true;
             if (!TIFFRGBAImageOK(m_tif, emsg)) {
-                error("No support for this flavor of TIFF file");
+                errorf("No support for this flavor of TIFF file (%s)", emsg);
                 return false;
             }
             // This falls back to looking like uint8 images
@@ -1140,49 +1130,31 @@ TIFFInput::readspec(bool read_meta)
         m_spec.erase_attribute("IPTC:Caption");
 
     // Because TIFF doesn't support arbitrary metadata, we look for certain
-    // hints in the ImageDescription and turn them into metadata.
+    // hints in the ImageDescription and turn them into metadata, also
+    // removing them from the ImageDescrption.
     bool updatedDesc = false;
-    static const char* fp_number_pattern
-        = "([+-]?((?:(?:[[:digit:]]*\\.)?[[:digit:]]+(?:[eE][+-]?[[:digit:]]+)?)))";
-    size_t found;
-    found = desc.rfind("oiio:ConstantColor=");
-    if (found != std::string::npos) {
-        size_t begin  = desc.find_first_of('=', found) + 1;
-        size_t end    = std::min(desc.find_first_of(' ', begin), desc.size());
-        string_view s = string_view(desc.data() + begin, end - begin);
-        m_spec.attribute("oiio:ConstantColor", s);
-        const std::string constcolor_pattern
-            = std::string("oiio:ConstantColor=(\\[?") + fp_number_pattern
-              + ",?)+\\]?[ ]*";
-        desc        = regex_replace(desc, regex(constcolor_pattern), "");
+    auto cc = Strutil::excise_string_after_head(desc, "oiio:ConstantColor=");
+    if (cc.size()) {
+        m_spec.attribute("oiio:ConstantColor", cc);
         updatedDesc = true;
     }
-    found = desc.rfind("oiio:AverageColor=");
-    if (found != std::string::npos) {
-        size_t begin  = desc.find_first_of('=', found) + 1;
-        size_t end    = std::min(desc.find_first_of(' ', begin), desc.size());
-        string_view s = string_view(desc.data() + begin, end - begin);
-        m_spec.attribute("oiio:AverageColor", s);
-        const std::string average_pattern
-            = std::string("oiio:AverageColor=(\\[?") + fp_number_pattern
-              + ",?)+\\]?[ ]*";
-        desc        = regex_replace(desc, regex(average_pattern), "");
+    auto ac = Strutil::excise_string_after_head(desc, "oiio:AverageColor=");
+    if (ac.size()) {
+        m_spec.attribute("oiio:AverageColor", ac);
         updatedDesc = true;
     }
-    found = desc.rfind("oiio:SHA-1=");
-    if (found == std::string::npos)  // back compatibility with < 1.5
-        found = desc.rfind("SHA-1=");
-    if (found != std::string::npos) {
-        size_t begin  = desc.find_first_of('=', found) + 1;
-        size_t end    = std::min(begin + 40, desc.size());
-        string_view s = string_view(desc.data() + begin, end - begin);
-        m_spec.attribute("oiio:SHA-1", s);
-        desc = regex_replace(desc, regex("oiio:SHA-1=[[:xdigit:]]*[ ]*"), "");
-        desc = regex_replace(desc, regex("SHA-1=[[:xdigit:]]*[ ]*"), "");
+    std::string sha = Strutil::excise_string_after_head(desc, "oiio:SHA-1=");
+    if (sha.empty())  // back compatibility with OIIO < 1.5
+        sha = Strutil::excise_string_after_head(desc, "SHA-1=");
+    if (sha.size()) {
+        m_spec.attribute("oiio:SHA-1", sha);
         updatedDesc = true;
     }
+
     if (updatedDesc) {
-        if (desc.size())
+        string_view d(desc);
+        Strutil::skip_whitespace(d);  // erase if it's only whitespace
+        if (d.size())
             m_spec.attribute("ImageDescription", desc);
         else
             m_spec.erase_attribute("ImageDescription");
@@ -2044,15 +2016,26 @@ TIFFInput::read_scanlines(int subimage, int miplevel, int ybegin, int yend,
         // by alpha should happen after we've already done data format
         // conversions. That's why we do it here, rather than in
         // read_native_blah.
+        int nchannels, alpha_channel, z_channel, width;
         {
             lock_guard lock(m_mutex);
-            if (format
-                == TypeUnknown)  // unknown means retrieve the native type
+            seek_subimage(subimage, miplevel);
+            nchannels     = m_spec.nchannels;
+            alpha_channel = m_spec.alpha_channel;
+            z_channel     = m_spec.z_channel;
+            width         = m_spec.width;
+            if (format == TypeUnknown)  // unknown == native type
                 format = m_spec.format;
         }
-        OIIO::premult(m_spec.nchannels, m_spec.width, yend - ybegin, 1, chbegin,
-                      chend, format, data, xstride, ystride, AutoStride,
-                      m_spec.alpha_channel, m_spec.z_channel);
+        // NOTE: if the channel range we read doesn't include the alpha
+        // channel, we don't have the alpha data to do the premult, so skip
+        // this. Pity the hapless soul who tries to read only the first
+        // three channels of an RGBA file with unassociated alpha. They will
+        // not get the premultiplication they deserve.
+        if (alpha_channel >= chbegin && alpha_channel < chend)
+            OIIO::premult(nchannels, width, yend - ybegin, 1, chbegin, chend,
+                          format, data, xstride, ystride, AutoStride,
+                          alpha_channel, z_channel);
     }
     return ok;
 }
@@ -2111,13 +2094,18 @@ TIFFInput::read_tiles(int subimage, int miplevel, int xbegin, int xend,
             nchannels     = m_spec.nchannels;
             alpha_channel = m_spec.alpha_channel;
             z_channel     = m_spec.z_channel;
-            if (format
-                == TypeUnknown)  // unknown means retrieve the native type
+            if (format == TypeUnknown)  // unknown == native type
                 format = m_spec.format;
         }
-        OIIO::premult(nchannels, xend - xbegin, yend - ybegin, zend - zbegin,
-                      chbegin, chend, format, data, xstride, ystride, zstride,
-                      alpha_channel, z_channel);
+        // NOTE: if the channel range we read doesn't include the alpha
+        // channel, we don't have the alpha data to do the premult, so skip
+        // this. Pity the hapless soul who tries to read only the first
+        // three channels of an RGBA file with unassociated alpha. They will
+        // not get the premultiplication they deserve.
+        if (alpha_channel >= chbegin && alpha_channel < chend)
+            OIIO::premult(nchannels, xend - xbegin, yend - ybegin,
+                          zend - zbegin, chbegin, chend, format, data, xstride,
+                          ystride, zstride, alpha_channel, z_channel);
     }
     return ok;
 }
